from distutils.core import setup

setup(
    name = 'jitu1',
    version = '1.0.0',
    py_modules = ['jitu1'],
    author = 'jiten',
    author_email = 'jitenbnsl@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
